==> haskell-dav-1.3.3-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-3QzrDopU4xkKgGoeLSwtAU
key: DAV-1.3.3-3QzrDopU4xkKgGoeLSwtAU
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: 098d3357f8d2f4d9aaf3312fd2447b23
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-3QzrDopU4xkKgGoeLSwtAU
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
    http-client-tls-0.3.5.3-GRzbTqIgjcC3ZLni0ogX0b
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-7eCzT8UL87gBol5kv4fZYX
    xml-hamlet-0.5.0-J86jIT0O5bi26DtOYplhb7
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.3-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-8BFGzIBbqXZ83dsClsdqb8
key: DAV-1.3.3-8BFGzIBbqXZ83dsClsdqb8
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: efe6c49af08422c0c035c55369eef3f7
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-8BFGzIBbqXZ83dsClsdqb8
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
    http-client-tls-0.3.5.3-9y2iT4zAqECLVoUMs9KIt
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-7eCzT8UL87gBol5kv4fZYX
    xml-hamlet-0.5.0-J86jIT0O5bi26DtOYplhb7
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
